# botlist/cogs

## A collection of cogs for use with [templatebot](https://github.com/vcokltfre/template-bot-v2)

### What's this?

This is a repository to store discord.py cogs that you're able to use with templatebot.

### Links

● [discord server](https://discord.gg/tWfaeNftAS)
